#!/bin/busybox sh

usage() {
    echo "Usage:"
    echo "  $0 [options] <target device file name> [ <image> ]"
    echo "Options:"
    echo "  -h"
    echo "     Show this help message."
    echo "  -s"
    echo "     Bytes in input, if not reading from file"
    echo "  -x"
    echo "     Mark image on target device unusable, wipe it out"
    echo
    echo "  image"
    echo "     image to be stored on device, if emtpy stdin is assumed"
    echo
    echo " Exit codes:"
    echo "   0:  Success."
    echo "   1:  Invalid arguments."
}

IMAGE_BYTES=
ERASE=

while getopts "hs:x" option; do
    case $option in
        h)
            usage
            exit 0
            ;;
        s)
            IMAGE_BYTES="$OPTARG"
            ;;
        x)
            ERASE=1
            ;;
        \?)
            usage
            exit 1
            ;;
    esac
done

shift $((OPTIND - 1))

DEVICE="$1"
IMAGE="${2:-"-"}"

if [ -z "$DEVICE" ] || [ ! -w "$DEVICE" ] ; then
    echo "ERROR missing device node $DEVICE"
    usage
    exit 1
fi

if [ $ERASE ]; then
    exec "$RESCUE_ROOT_DIR"/usr/sbin/ubiupdatevol "$DEVICE" --truncate
fi

if [ "$IMAGE" = "-" ]; then
    if [ -z "$IMAGE_BYTES" ]; then
        echo "ERROR need size of image when reading from stdin"
        exit 1
    fi
else
    if [ -z "$IMAGE" ] || [ ! -r "$IMAGE" ]; then
        echo "ERROR file not readable '$IMAGE'"
        exit 2
    fi
fi

# TODO check size of target partition

IMAGE_BYTES_STRING=""
if [ -n "$IMAGE_BYTES" ]; then
    IMAGE_BYTES_STRING="-s $IMAGE_BYTES"
fi

exec "$RESCUE_ROOT_DIR"/usr/sbin/ubiupdatevol "$DEVICE"\
    $IMAGE_BYTES_STRING\
    "$IMAGE"
